var testUtils     = require('../../../utils'),
    should        = require('should'),
    supertest     = require('supertest'),
    config        = require('../../../../../core/server/config'),
    ghost         = testUtils.startGhost,
    request;

describe('Configuration API', function () {
    var accesstoken = '', ghostServer;

    before(function (done) {
        // starting ghost automatically populates the db
        // TODO: prevent db init, and manage bringing up the DB with fixtures ourselves
        ghost().then(function (_ghostServer) {
            ghostServer = _ghostServer;
            return ghostServer.start();
        }).then(function () {
            request = supertest.agent(config.get('url'));
        }).then(function () {
            return testUtils.doAuth(request);
        }).then(function (token) {
            accesstoken = token;
            done();
        }).catch(done);
    });

    after(function () {
        return testUtils.clearData()
            .then(function () {
                return ghostServer.stop();
            });
    });

    describe('success', function () {
        it('can retrieve public configuration', function (done) {
            request.get(testUtils.API.getApiQuery('configuration/'))
                .expect('Content-Type', /json/)
                .expect('Cache-Control', testUtils.cacheRules.private)
                .expect(200)
                .end(function (err, res) {
                    should.exist(res.body.configuration);
                    done();
                });
        });
    });
});
